@@ -46,16 +46,32 @@ class RayoHandler:
         """
 
         payload = {
-            'has_pickup': 0,
+            'has_pickup': 1,
             'has_delivery': 1,
             'auto_assignment': 0,
-            'order_id': instance.purchase_number,
+            'order_id': instance.reference,
             'tags': '',
             'id_store': api_settings.RAYO['STORE'],
-            'pickups': [],
+            'pickups': [
+                {
+                    'address': api_settings.SENDER['CD_ADDRESS'],
+                    'address2': '',
+                    'comuna': api_settings.SENDER['CD_COMMUNE'],
+                    'city': api_settings.SENDER['CD_CITY'],
+                    'state': api_settings.SENDER['CD_STATE'],
+                    'country': api_settings.SENDER['COUNTRY'],
+                    'job_description': "Retiro Bodega",
+                    'phone': '',
+                    'name': f'Retiro de orden: {instance.reference}',
+                    'metadata_name': api_settings.RAYO['METADATA_NAME'],
+                    'metadata': {},
+                    'email': '',
+                }
+            ],
             'deliveries': [
                 {
                     'address': f'{instance.address.street} {instance.address.number}',
+                    'address2': instance.address.unit,
                     'comuna': instance.commune.name,
                     'city': '',
                     'state': instance.region.name,
@@ -88,6 +104,8 @@ class RayoHandler:
                     'tracking_url': response['deliveries'][0]['url_tracking_pickup'],
                 })
                 return response
+            else:
+                raise ConnectorException(response.get('message'), 'Error requesting create shipping', 500)
 
         except ConnectorException as error:
             logger.error(error)
